# Moxa x86 Linux SDK Wizard

## Introduction

The Moxa x86 Linux SDK enables the easy deployment on the Moxa x86 IPC platform. The SDK contains components for peripheral drivers, peripheral control tools and configuration files. It also provides deployment features, such as build & installation log, dry-run, and selftest on target model.

## SDK Structure

The x86 Linux SDK zip file consists of the following files:
```
<wizard>.tgz - the tarball file of x86 Linux SDK Install Wizard
README.docx  - this file in docx format
sources_list - the list of source of x86 Linux SDK Install Wizard
build_info   - x86 Linux SDK build information
```

## Support Models and Linux Distributions
| **Model Name** | **Debian 11** | **Ubuntu 22.04** | **RHEL 9** |
| - | - | - | - |
| RKP-A110 | V | V | V |
| RKP-C110 | V | V | V |
| BXP-A100 | V | V | V |
| BXP-C100 | V | V | V |
| DRP-A100 | V | V | V |
| DRP-C100 | V | V | V |

## Build from x86 Linux Install Wizard

Moxa offers a release of the x86 Linux Install Wizard tarball file.
The release is different in some functionality as documented **CHANGELOG** in the repository.

### Extract the released tarball file
> **Warning**: Please extract the tarball file under Linux OS environment
```
tar xvf Moxa_x86_Linux_Install_Wizard_<ver>_Build_<build_date>.tgz
cd Moxa_x86_Linux_Install_Wizard_<ver>_Build_<build_date>
```

### x86 Linux Install Wizard Structure
- The x86 Linux Install Wizard consists of the following directories and files:

```
product.d/ - congfiguration files for products
scripts/   - install wizard generic programs
src/       - source code for the drivers and tools
install.sh - entry program for build and install the SDK
README.md  - this file: introduction and build instructions
CHANGELOG  - change log and difference to the SDK release
LICENSE    - MOXA license statement file
version    - current version of x86 Linux Install Wizard
```

### Prerequisites
- A system running Linux (Debian, Ubuntu, RedHat)
- Access to the terminal/command line
- A user account with **sudo/root** privileges
- Connect to network


> Note: Before building, it will need to install development tool from network

### Display help page
Show a short usage summary

- Command
```
./install.sh --help
```
- Result
```

                ███╗   ███╗ ██████╗ ██╗  ██╗ █████╗
                ████╗ ████║██╔═══██╗╚██╗██╔╝██╔══██╗
                ██╔████╔██║██║   ██║ ╚███╔╝ ██║  ██║
                ██║╚██╔╝██║██║   ██║ ██╔██╗ ██║  ██║
                ██║ ╚═╝ ██║╚██████╔╝██╔╝ ██╗██║  ██║
                ╚═╝     ╚═╝ ╚═════╝ ╚═╝  ╚═╝╚═╝  ╚═╝
                ------------------------------------
                         X86 INSTALL WIZARD

Usage: install.sh [option]

Options:
        -h, --help         Display this help page
        -y, --yes          Automatically answer yes
        -v, --version      Display the version information
        -s, --selftest     Run the self test cases
            --dry-run      List available driver and tool only
            --uninstall    Uninstall driver and tool
            --force        Install driver and tool even if the
                           version is the same or older (default is
                           to install newer version)

Without passing any option, it would run the installation directly.
```

### Display x86 Install Wizard version

- Command
```
./install.sh --version
```
- Expected result
```
1.0.0
```

### How to Use the `--yes` Option
The `--yes` (alternatively, `-y`) option automatically answers yes to any prompts

It can use with others options as below
- Assume "yes" as answer to all prompts during installation process
```
./install.sh --yes
```
- Assume "yes" as answer to all prompts during uninstallation process
```
./install.sh --yes --uninstall
```

### How to Use the `--dry-run` Option
The `--dry-run` option simulates what would install, but doesn't actually change anything on your system

- Command
```
./install.sh --dry-run
```
- Expected result (RKP-A110)
  - Name: driver or tool source name
  - Version: driver or tool source version which is available to install
  - Tag: driver or tool source git tag name
```
----------------------------------------------------------------------
 Product Name: RKPA110
----------------------------------------------------------------------
 Name                          Version                  Tag
======================================================================
 moxa-it87-gpio-driver         5.2+1.5.0-1              master
 moxa-it87-wdt-driver          5.2+1.5.0-1              5.2-master
 moxa-it87-serial-driver       1.4.1+u2                 master
 moxa-mxuport-driver           5.1.1_build_23080316     5.x-5.1.1_build_23080316-develop
 moxa-x86-control-tools        1.8.1                    master
----------------------------------------------------------------------
```

### Build and Install
Default is to install newer version. If you want to install the same or older, please use the `--force` option

- Command
```
./install.sh
```
> Note: Please run with **sudo/root** privileges

- Expected result (RKP-A110)
```
[info] Product Name: RKPA110
[info] OS Name: Ubuntu
[info] OS Version: 22.04
[info] Kernel Info: Linux moxa 5.19.0-32-generic #33~22.04.1-Ubuntu SMP PREEMPT_DYNAMIC Mon Jan 30 17:03:34 UTC 2 x86_64 x86_64 x86_64 GNU/Linux
Do you want to continue? [Y/n]y
[info] >>> Execute hook script "install-dev-tools.sh".
[info] <<< Execute hook script "install-dev-tools.sh" done.
[info] >>> Execute hook script "build-and-install-source.sh".
[info] === Run pre-install
[info] === Install driver
Do you want to install moxa-it87-gpio-driver (5.2+1.5.0-1)? [Y/n]y
[info] Installing moxa-it87-gpio-driver (5.2+1.5.0-1)
Do you want to install moxa-it87-wdt-driver (5.2+1.5.0-1)? [Y/n]y
[info] Installing moxa-it87-wdt-driver (5.2+1.5.0-1)
...
... (skip)
...
[info] Done. Please reboot machine for installation to take effect.
Do you want to reboot now? [Y/n]
```
And finally, you'll see a prompt asking if you want to reboot the system

```
Do you want to reboot now? [Y/n]
```

Enter `y`, `Y`, or `yes` to reboot the system, or `n`, `N`, or `no` to exit out of install process

### Check the status of deployment
After build and install, you can run `--selftest` option to check the status.

- Command
```
./install.sh --selftest
```
- Expected result (RKP-A110)
  - Name: driver or tool source name
  - Installed: show the driver or tool is installed or not
  - Status: show the driver is load or not and tool related information
  - Version: driver or tool source version which is installed
```
[info] Product Name: RKPA110
[info] OS Name: Ubuntu
[info] OS Version: 22.04
[info] Kernel Info: Linux moxa 5.19.0-32-generic #33~22.04.1-Ubuntu SMP PREEMPT_DYNAMIC Mon Jan 30 17:03:34 UTC 2 x86_64 x86_64 x86_64 GNU/Linux
[info] >>> Execute hook script "self-test.sh".
[info] ---------------------------------------------------------------------------
[info]  Name                          Installed      Status         Version
[info] ===========================================================================
[info]  moxa-it87-gpio-driver                                       5.2+1.5.0-1
[info]  - gpio_it87                   Yes            Loaded
[info]  moxa-it87-wdt-driver                                        5.2+1.5.0-1
[info]  - it87_wdt                    Yes            Loaded
[info]  - watchdog service            Yes            Active
[info]  moxa-it87-serial-driver                                     1.4.1+u2
[info]  - it87_serial                 Yes            Loaded
[info]  moxa-mxuport-driver                                         5.1.1_build_23080316
[info]  - mxuport                     Yes            Loaded
[info]  moxa-x86-control-tools                                      1.8.1
[info]  - mx-uart-ctl                 Yes            6 ports
[info]  - mx-dio-ctl                  Yes            8 DI / 8 DO
[info] ---------------------------------------------------------------------------
[info] <<< Execute hook script "self-test.sh" done.
```

### Uninstall
Uninstall is identical to install except that driver and tool are removed instead of installed

- Command
```
./install.sh --uninstall
```
> Note: Please run with **sudo/root** privileges

- Expected result (RKP-A110)
```
[info] Product Name: RKPA110
[info] OS Name: Ubuntu
[info] OS Version: 22.04
[info] Kernel Info: Linux moxa 5.19.0-32-generic #33~22.04.1-Ubuntu SMP PREEMPT_DYNAMIC Mon Jan 30 17:03:34 UTC 2 x86_64 x86_64 x86_64 GNU/Linux
Do you want to continue? [Y/n]y
[info] >>> Execute hook script "uninstall.sh".
[info] === Uninstall driver
Do you want to uninstall moxa-it87-gpio-driver (5.2+1.5.0-1)? [Y/n]y
[info] Uninstall moxa-it87-gpio-driver (5.2+1.5.0-1)
Do you want to uninstall moxa-it87-wdt-driver (5.2+1.5.0-1)? [Y/n]y
[info] Uninstall moxa-it87-wdt-driver (5.2+1.5.0-1)
[info]  Remove Watchdog Service
Do you want to uninstall moxa-it87-serial-driver (1.4.1+u2)? [Y/n]y
[info] Uninstall moxa-it87-serial-driver (1.4.1+u2)
...
... (skip)
...
[info] <<< Execute hook script "uninstall.sh" done.
[info] Done. Please reboot machine for uninstallation to take effect.
Do you want to reboot now? [Y/n]
```
And finally, you'll see a prompt asking if you want to reboot the system

```
Do you want to reboot now? [Y/n]
```

Enter `y`, `Y`, or `yes` to reboot the system, or `n`, `N`, or `no` to exit out of uninstall process

### Log file
Finally, if user wants to see the log of build and install stage, the log file is located on the same build folder **install.log**

- Command
```
cat install.log
```

## Peripheral Control Tool

### Moxa x86 Control Tools

### [UART] Moxa Serial Port Control
The purpose of Moxa serial port mode control tool **mx-uart-ctl** is for getting and setting serial UART ports mode.

- Available models
  - BXP-A100/BXP-C100
  - RKP-A110/RKP-C110
  - DRP-A100/DRP-C100

- Usage of **mx-uart-ctl**

```
Usage:
                mx-uart-ctl -p <port_number> [-m <uart_mode>]

OPTIONS:
                -p <port_number>
                                Set target port.
                -m <uart_mode>
                                Set target port to uart_mode
                                0 --> set to RS-232 mode
                                1 --> set to RS-485-2W mode
                                2 --> set to RS-422 mode
                                3 --> set to RS-485-4W mode

Example:
                Get mode from port 0
                # mx-uart-ctl -p 0

                Set port 1 to mode RS232
                # mx-uart-ctl -p 1 -m 0
```

### [DIO] Moxa Digital IO Port Control
Moxa DIO port control tool **mx-dio-ctl** is for getting DI/DO and setting DO ports status (low/high).

- Available models
  - BXP-A100/BXP-C100
  - RKP-A110/RKP-C110

- Usage of **mx-dio-ctl**

```
Usage:
        mx-dio-ctl <-i|-o <#port number> [-s <#state>]>

OPTIONS:
        -i <#DIN port number>
        -o <#DOUT port number>
        -s <#state>
                Set state for target DOUT port
                0 --> LOW
                1 --> HIGH

Example:
        Get value from DIN port 0
        # mx-dio-ctl -i 0
        Get value from DOUT port 0
        # mx-dio-ctl -o 0

        Set DOUT port 0 value to LOW
        # mx-dio-ctl -o 0 -s 0
        Set DOUT port 0 value to HIGH
        # mx-dio-ctl -o 0 -s 1
```

## Change Log
- v1.2 - 2023-10-05
  1. Compatible SDK Version **1.0**
  2. Show number of DI/DO in selftest result

- v1.1 - 2023-09-13
  1. Compatible SDK Version **1.3.0**
  2. Add `--force` option description
  3. Revise prerequisites chapter

- v1.0 - 2023-08-30
  1. Compatible SDK Version **1.2.0**
  2. Initial Content
