#!/bin/bash -e
#
# Copyright (C) 2023 MOXA Inc. All rights reserved.
# This software is distributed under the terms of the MOXA SOFTWARE NOTICE.
# See the file LICENSE for details.
#

set -e

source "${INSTL_SCRIPT_DIR}/lib/util.sh"
source "${INSTL_SCRIPT_DIR}/lib/logger.sh"
log::init "${INSTL_LOG_FILE}" "${INSTL_LOG_LEVEL}"

main() {
        log::info "Rename serial device with ttyMX"
        cat <<EOF >/etc/udev/rules.d/99-moxa-x86-serial-naming.rules
KERNEL=="ttyS0"   DRIVERS=="serial"  MODE="0660" SYMLINK+="ttyM0"
KERNEL=="ttyS1"   DRIVERS=="serial"  MODE="0660" SYMLINK+="ttyM1"
KERNEL=="ttyUSB0" DRIVERS=="mxuport" MODE="0660" SYMLINK+="ttyM2"
KERNEL=="ttyUSB1" DRIVERS=="mxuport" MODE="0660" SYMLINK+="ttyM3"
KERNEL=="ttyUSB2" DRIVERS=="mxuport" MODE="0660" SYMLINK+="ttyM4"
KERNEL=="ttyUSB3" DRIVERS=="mxuport" MODE="0660" SYMLINK+="ttyM5"
KERNEL=="ttyUSB4" DRIVERS=="mxuport" MODE="0660" SYMLINK+="ttyM6"
KERNEL=="ttyUSB5" DRIVERS=="mxuport" MODE="0660" SYMLINK+="ttyM7"
KERNEL=="ttyUSB6" DRIVERS=="mxuport" MODE="0660" SYMLINK+="ttyM8"
KERNEL=="ttyUSB7" DRIVERS=="mxuport" MODE="0660" SYMLINK+="ttyM9"
EOF
        {
                udevadm control --reload-rules
                udevadm trigger
        } >>"${INSTL_LOG_FILE}"

        if [[ "${LINUX_DISTRO_ID}" == "debian" ]]; then
                if ! util::is_exists "/dev/dri/card0" && util::is_exists "/etc/X11/default-display-manager"; then
                        log::info "Graphics device is not properly supported by the driver. Force probe it."
                        {
                                local device_pci_id

                                for bus in "/sys/devices/pci0000:00/0000"*; do
                                        # 0x030000 means VGA Display controller
                                        if [[ "$(cat "$bus"/class)" == "0x030000" ]]; then
                                                device_pci_id=$(cat "$bus"/device 2>/dev/null)
                                                break
                                        fi
                                done

                                if ! util::is_empty_str "$device_pci_id"; then
                                        if ! grep -wq "i915.force_probe" "/etc/default/grub"; then
                                                sed -i "s/GRUB_CMDLINE_LINUX=\"[^\"]*/& i915.force_probe=${device_pci_id#"0x"}/" /etc/default/grub
                                                update-grub2
                                        fi

                                        if add-apt-repository "deb http://deb.debian.org/debian/ bullseye main non-free"; then
                                                apt-get update
                                                apt-get install firmware-linux -y
                                        fi
                                else
                                        log::warn " Can not get graphics device PCI ID"
                                fi

                        } >>"${INSTL_LOG_FILE}" 2>&1
                fi
        fi
}

main
