#!/bin/bash
#
# Copyright (C) 2023 MOXA Inc. All rights reserved.
# This software is distributed under the terms of the MOXA SOFTWARE NOTICE.
# See the file LICENSE for details.
#
# Authors:
#       2023  Wilson YS Huang  <wilsonys.huang@moxa.com>

source "${INSTL_SCRIPT_DIR}/lib/util.sh"
source "${INSTL_SCRIPT_DIR}/lib/logger.sh"
log::init "${INSTL_LOG_FILE}" "${INSTL_LOG_LEVEL}"

set -e

REPO_NAME="moxa-it87-gpio-driver"
SRC_PATH_PREFIX="${INSTL_TOP_DIR}/src/${REPO_NAME}"

main() {
        local src_tag
        local src_ver
        src_tag="$1"
        src_ver="$2"

        log::info "Installing ${REPO_NAME} (${src_ver})"

        {
                pushd "${SRC_PATH_PREFIX}-${src_tag}" >/dev/null

                make clean
                make install
                make load

                popd
        } >>"${INSTL_LOG_FILE}" 2>&1

        if ! /sbin/ldconfig -p | grep -q "libgpiod"; then
                log::info " Installing libgpiod"

                case "${LINUX_DISTRO_ID}" in
                "debian" | "ubuntu")
                        {
                                apt-get update
                                apt-get install autoconf \
                                        autoconf-archive libtool \
                                        pkg-config -y
                        } >>"${INSTL_LOG_FILE}" 2>&1

                        ;;
                "rhel" | "centos")
                        {
                                yum makecache
                                yum install autoconf \
                                        autoconf-archive libtool \
                                        pkg-config -y
                        } >>"${INSTL_LOG_FILE}" 2>&1
                        ;;
                esac

                {
                        pushd "$INSTL_TOP_DIR/src/libgpiod-master" >/dev/null
                        ./autogen.sh --enable-tools=yes
                        make -j"$(nproc)"
                        make install
                        ldconfig /usr/local/lib/
                        popd
                } >>"${INSTL_LOG_FILE}" 2>&1
        fi
}

main "$@"
